==> estateplat-common-1.2.4-20201125.025652-547-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJyht.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by Mr.GG on 2018/2/11 0011.
 */
@Table(name = "bdc_jyht")
public class BdcJyht implements Serializable,InsertVo {
    @Id
    private String jyhtid;  //交易合同id
    private String jybh;  //交易编号
    private String htbh;  //合同编号
    private String htfwm;  //合同防伪码
    private Date basj;  //备案时间
    private String htzt;  //合同状态
    private Double htje;  //合同金额
    private String zl;  //坐落
    private Double jzmj;  //建筑面积
    private String htlx;  //合同类型
    private String zjjg;  //中介机构
    private String zjjgdm;  //中介机构社会征信代码
    private String bz;  //备注
    private String drr;  //导入人
    private Date drsj;  //导入时间
    private String proid;  //项目id
    private String jyyfczh;  //交易原房产证号
    private String ytmc;  //用途名称
    private String shzt;// 审核状态
    private String shyj;// 审核意见
    private String sfjs;//是否交税
    private Date jssj;//交税时间
    private String sfhs;//是否交税

    public String getJyhtid() {
        return jyhtid;
    }

    public void setJyhtid(String jyhtid) {
        this.jyhtid = jyhtid;
    }

    public String getJybh() {
        return jybh;
    }

    public void setJybh(String jybh) {
        this.jybh = jybh;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getHtfwm() {
        return htfwm;
    }

    public void setHtfwm(String htfwm) {
        this.htfwm = htfwm;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public String getHtzt() {
        return htzt;
    }

    public void setHtzt(String htzt) {
        this.htzt = htzt;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getHtlx() {
        return htlx;
    }

    public void setHtlx(String htlx) {
        this.htlx = htlx;
    }

    public String getZjjg() {
        return zjjg;
    }

    public void setZjjg(String zjjg) {
        this.zjjg = zjjg;
    }

    public String getZjjgdm() {
        return zjjgdm;
    }

    public void setZjjgdm(String zjjgdm) {
        this.zjjgdm = zjjgdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDrr() {
        return drr;
    }

    public void setDrr(String drr) {
        this.drr = drr;
    }

    public Date getDrsj() {
        return drsj;
    }

    public void setDrsj(Date drsj) {
        this.drsj = drsj;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getJyyfczh() {
        return jyyfczh;
    }

    public void setJyyfczh(String jyyfczh) {
        this.jyyfczh = jyyfczh;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getSfjs() {
        return sfjs;
    }

    public void setSfjs(String sfjs) {
        this.sfjs = sfjs;
    }

    public String getSfhs() {
        return sfhs;
    }

    public void setSfhs(String sfhs) {
        this.sfhs = sfhs;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }
}

==> estateplat-common-1.2.4-20210429.092621-739-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJyht.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by Mr.GG on 2018/2/11 0011.
 */
@Table(name = "bdc_jyht")
public class BdcJyht implements Serializable,InsertVo {
    @Id
    private String jyhtid;  //交易合同id
    private String jybh;  //交易编号
    private String htbh;  //合同编号
    private String htfwm;  //合同防伪码
    private Date basj;  //备案时间
    private String htzt;  //合同状态
    private Double htje;  //合同金额
    private String zl;  //坐落
    private Double jzmj;  //建筑面积
    private String htlx;  //合同类型
    private String zjjg;  //中介机构
    private String zjjgdm;  //中介机构社会征信代码
    private String bz;  //备注
    private String drr;  //导入人
    private Date drsj;  //导入时间
    private String proid;  //项目id
    private String jyyfczh;  //交易原房产证号
    private String ytmc;  //用途名称
    private String shzt;// 审核状态
    private String shyj;// 审核意见
    private String sfjs;//是否交税
    private Date jssj;//交税时间
    private String sfhs;//是否交税
    private Date htqdsj;//合同签订时间

    public String getJyhtid() {
        return jyhtid;
    }

    public void setJyhtid(String jyhtid) {
        this.jyhtid = jyhtid;
    }

    public String getJybh() {
        return jybh;
    }

    public void setJybh(String jybh) {
        this.jybh = jybh;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getHtfwm() {
        return htfwm;
    }

    public void setHtfwm(String htfwm) {
        this.htfwm = htfwm;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public String getHtzt() {
        return htzt;
    }

    public void setHtzt(String htzt) {
        this.htzt = htzt;
    }

    public Double getHtje() {
        return htje;
    }

    public void setHtje(Double htje) {
        this.htje = htje;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getHtlx() {
        return htlx;
    }

    public void setHtlx(String htlx) {
        this.htlx = htlx;
    }

    public String getZjjg() {
        return zjjg;
    }

    public void setZjjg(String zjjg) {
        this.zjjg = zjjg;
    }

    public String getZjjgdm() {
        return zjjgdm;
    }

    public void setZjjgdm(String zjjgdm) {
        this.zjjgdm = zjjgdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getDrr() {
        return drr;
    }

    public void setDrr(String drr) {
        this.drr = drr;
    }

    public Date getDrsj() {
        return drsj;
    }

    public void setDrsj(Date drsj) {
        this.drsj = drsj;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getJyyfczh() {
        return jyyfczh;
    }

    public void setJyyfczh(String jyyfczh) {
        this.jyyfczh = jyyfczh;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getShzt() {
        return shzt;
    }

    public void setShzt(String shzt) {
        this.shzt = shzt;
    }

    public String getShyj() {
        return shyj;
    }

    public void setShyj(String shyj) {
        this.shyj = shyj;
    }

    public String getSfjs() {
        return sfjs;
    }

    public void setSfjs(String sfjs) {
        this.sfjs = sfjs;
    }

    public String getSfhs() {
        return sfhs;
    }

    public void setSfhs(String sfhs) {
        this.sfhs = sfhs;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public Date getHtqdsj() {
        return htqdsj;
    }

    public void setHtqdsj(Date htqdsj) {
        this.htqdsj = htqdsj;
    }
}
